@@ -33,12 +33,6 @@ from etcd3gw import exceptions
 from etcd3gw.tests import base
 from etcd3gw import utils
 
-try:
-    # Python 3.8 : time.clock was deprecated and removed.
-    from time import perf_counter as clock
-except ImportError:
-    from time import clock
-
 
 def _is_etcd3_running():
     try:
@@ -51,7 +45,7 @@ def _is_etcd3_running():
 class TestEtcd3Gateway(base.TestCase):
     @classmethod
     def setUpClass(cls):
-        cls.client = Etcd3Client()
+        cls.client = Etcd3Client(api_path='/v3/')
 
     @unittest.skipUnless(
         _is_etcd3_running(), "etcd3 is not available")
@@ -288,6 +282,51 @@ class TestEtcd3Gateway(base.TestCase):
 
         t.join()
 
+    @unittest.skipUnless(
+        _is_etcd3_running(), "etcd3 is not available")
+    def test_watch_huge_payload(self):
+        key = '/%s-watch_key/watch/huge_payload' % str(uuid.uuid4())
+
+        def update_etcd(v):
+            print(f"put({key}, {v}")
+            self.client.put(key, v)
+            out = self.client.get(key)
+            self.assertEqual([v.encode("latin-1")], out)
+
+        def update_key():
+            # sleep to make watch can get the event
+            time.sleep(3)
+            update_etcd('0' * 10000)
+            time.sleep(1)
+            update_etcd('1' * 10000)
+            time.sleep(1)
+            update_etcd('2' * 10000)
+            time.sleep(1)
+            update_etcd('3' * 10000)
+            time.sleep(1)
+
+        t = threading.Thread(name="update_key_huge", target=update_key)
+        t.start()
+
+        change_count = 0
+        events_iterator, cancel = self.client.watch(key)
+        for event in events_iterator:
+            self.assertEqual(event['kv']['key'], key.encode("latin-1"))
+            self.assertEqual(
+                event['kv']['value'],
+                (str(change_count) * 10000).encode("latin-1"),
+            )
+
+            # if cancel worked, we should not receive event 3
+            assert event['kv']['value'][0] != b'3'
+
+            change_count += 1
+            if change_count > 2:
+                # if cancel not work, we will block in this for-loop forever
+                cancel()
+
+        t.join()
+
     @unittest.skipUnless(
         _is_etcd3_running(), "etcd3 is not available")
     def test_watch_prefix(self):
@@ -368,7 +407,7 @@ class TestEtcd3Gateway(base.TestCase):
     @unittest.skipUnless(
         _is_etcd3_running(), "etcd3 is not available")
     def test_client_locks(self):
-        lock = self.client.lock(id='xyz-%s' % clock(), ttl=60)
+        lock = self.client.lock(id='xyz-%s' % time.perf_counter(), ttl=60)
         self.assertIsNotNone(lock)
 
         self.assertTrue(lock.acquire())
